#
# Cookbook Name:: rsdns
# Recipe:: default
#
# Copyright 2012, Rackspace Hosting
#
# All rights reserved - Do Not Redistribute
#

#Install git
case node[:platform]
when "debian", "ubuntu"
  package "git-core"
else
  package "git"
end

#Install the rsdns tools from github
script "install rsdns" do
  interpreter "bash"
  user "root"
  cwd "/tmp"
  code <<-EOH
    git clone https://github.com/linickx/rsdns.git /opt/rsdns
  EOH
  not_if "test -f /opt/rsdns/rsdns"
end

link "/usr/local/bin/rsdns" do
  to "/opt/rsdns/rsdns"
end

if Chef::DataBag.list.keys.include?("rackspace") && data_bag("rackspace").include?("cloud")
  #Access the Rackspace Cloud encrypted data_bag
  raxcloud = Chef::EncryptedDataBagItem.load("rackspace","cloud")

  #Create variables for the Rackspace Cloud username and apikey
  raxusername = raxcloud['raxusername']
  raxapikey = raxcloud['raxapikey']
else
        Chef::Log.info "rackspace data bag with item cloud does not exist, skip adding user and api to ./root/rsdns_config"
end

#Create the .raxrc with credentials in /root
template "/root/.rsdns_config" do
  source "rsdns_config.erb"
  owner "root"
  group "root"
  mode 0640
  variables(
    :raxusername => raxusername,
    :raxapikey => raxapikey
  )
end
